==> recoveryimage-s_series-1.0.16.tar: ysbin/firmwareupgrade.sh <==
#!/bin/sh
logdir=/ysdisk/cache/firmware
imagedir=/ysdisk/imageupdate
firmwareimage=/ysdisk/imageupdate/uImage
invaildflag=/ysdisk/imageupdate/invaildimage
detectflag=/ysdisk/imageupdate/detectimage
nofoundflag=/ysdisk/imageupdate/nofoundimage
tmpfilename=uImage.tmp
worklefile=/tmp/workled.conf
wgettimeout=15

mode=$2
reset=$3
tftpserver=$4
tftpfile=$5
httpurl=$4
uploadfilepath=$4
if [ ! -d $imagedir ];then
	mkdir -p $imagedir
fi
if [ ! -d $logdir ];then
	mkdir -p $logdir
fi
if [ "$1" == "start" ];then
	if [ -f $firmwareimage ];then
		rm $firmwareimage
	fi
	if [ -f $invaildflag ];then
		rm $invaildflag
	fi
	if [ -f $detectflag ];then
		rm $detectflag
	fi
	if [ -f $nofoundflag ];then
		rm $nofoundflag
	fi
	echo 100 > $worklefile 
	cd $logdir
	rm $tmpfilename
	rm $firmwareimage
	if [ "$mode" == "tftp" ];then
		killall -9 tftp
		/bin/tftp -g -r $tftpfile -l $tmpfilename $tftpserver
		srcfile=$tmpfilename
	elif [ "$mode" == "http" ];then
		/bin/wget -O $tmpfilename $httpurl -t 2 -T $wgettimeout
		srcfile=$tmpfilename
	elif [ "$mode" == "upload" ];then
		srcfile=$uploadfilepath
	elif [ "$mode" == "auto" ];then
		/ysbin/cloudfirmware upgrade
		srcfile=$tmpfilename
	fi
#detect firm correct
	touch $detectflag
	if [ ! -e $srcfile ] || [ ! -s $srcfile ];then
		imagestatu=-1
		touch $nofoundflag
		logger "firmwareupgrade: no found image"
	else
		/bin/firmware_detect $srcfile yes
		imagestatu=$?
	fi
	if [ "$imagestatu" == "0" ];then
		#firmware is vaild
		if [ "$reset" == "yes" ];then
			touch /ysdisk/etc/.reset
		fi
		mv $srcfile ${firmwareimage}.bin
		date > ${firmwareimage}
		if [ -f $firmwareimage ];then
			cp /etc/version $imagedir/oldversion
			/ysbin/sleeprun.sh /sbin/reboot 3
		fi
	else
		logger "firmwareupgrade: this is invaild image"
		#firmware is invaild,delete it
		touch $invaildflag 
		rm $srcfile
	fi
	rm $detectflag
	rm $worklefile 
elif [ "$1" == "stop" ];then
	rm $worklefile 
	rm $tmpfilename
	rm $firmwareimage
	killall -9 firmwareupgrade.sh
fi

==> recoveryimage-s_series_v4-65.0.5.tar: ysbin/firmwareupgrade.sh <==
#!/bin/sh
logdir=/ysdisk/cache/firmware
imagedir=/ysdisk/imageupdate
firmwareimage=/ysdisk/imageupdate/uImage
invaildflag=/ysdisk/imageupdate/invaildimage
detectflag=/ysdisk/imageupdate/detectimage
nofoundflag=/ysdisk/imageupdate/nofoundimage
tmpfilename=uImage.tmp
worklefile=/tmp/workled.conf
wgettimeout=15

mode=$2
reset=$3
tftpserver=$4
tftpfile=$5
httpurl=$4
uploadfilepath=$4
if [ ! -d $imagedir ];then
	mkdir -p $imagedir
fi
if [ ! -d $logdir ];then
	mkdir -p $logdir
fi
if [ "$1" == "start" ];then
	if [ -f $firmwareimage ];then
		rm $firmwareimage
	fi
	if [ -f $invaildflag ];then
		rm $invaildflag
	fi
	if [ -f $detectflag ];then
		rm $detectflag
	fi
	if [ -f $nofoundflag ];then
		rm $nofoundflag
	fi
	echo 100 > $worklefile 
	cd $logdir
	rm $tmpfilename
	rm $firmwareimage
	if [ "$mode" == "tftp" ];then
		killall -9 tftp
		/usr/bin/tftp -g -r $tftpfile -l $tmpfilename $tftpserver
		srcfile=$tmpfilename
	elif [ "$mode" == "http" ];then
		/bin/wget -O $tmpfilename $httpurl -t 2 -T $wgettimeout
		srcfile=$tmpfilename
	elif [ "$mode" == "upload" ];then
		srcfile=$uploadfilepath
	elif [ "$mode" == "auto" ];then
		/ysbin/cloudfirmware upgrade
		srcfile=$tmpfilename
	fi
#detect firm correct
	touch $detectflag
	if [ ! -e $srcfile ] || [ ! -s $srcfile ];then
		imagestatu=-1
		touch $nofoundflag
		logger "firmwareupgrade: no found image"
	else
		/bin/firmware_detect $srcfile yes
		imagestatu=$?
	fi
	if [ "$imagestatu" == "0" ];then
		#firmware is vaild
		if [ "$reset" == "yes" ];then
			touch /ysdisk/etc/.reset
		fi
		mv $srcfile ${firmwareimage}.bin
		date > ${firmwareimage}
		if [ -f $firmwareimage ];then
			cp /etc/version $imagedir/oldversion
			/ysbin/sleeprun.sh /sbin/reboot 3
		fi
	else
		logger "firmwareupgrade: this is invaild image"
		#firmware is invaild,delete it
		touch $invaildflag 
		rm $srcfile
	fi
	rm $detectflag
	rm $worklefile 
elif [ "$1" == "stop" ];then
	rm $worklefile 
	rm $tmpfilename
	rm $firmwareimage
	killall -9 firmwareupgrade.sh
fi
